"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, function_name: str, qualifier: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the version-specific settings of a Lambda function or version. The output includes only options that can vary between versions of a function. To modify these settings, use UpdateFunctionConfiguration. To get all of a function's details, including function-level settings, use GetFunction.

    Args:
        function_name(str): The name of the Lambda function, version, or alias.  Name formats     Function name - my-function (name-only), my-function:v1 (with alias).    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.    Partial ARN - 123456789012:function:my-function.   You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
        qualifier(str, optional): Specify a version or alias to get details about a published version of the function. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.function.configuration.get(ctx, function_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.function.configuration.get function_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="get_function_configuration",
        op_kwargs={"FunctionName": function_name, "Qualifier": qualifier},
    )


async def update(
    hub,
    ctx,
    function_name: str,
    role: str = None,
    handler: str = None,
    description: str = None,
    timeout: int = None,
    memory_size: int = None,
    vpc_config: Dict = None,
    environment: Dict = None,
    runtime: str = None,
    dead_letter_config: Dict = None,
    kms_key_arn: str = None,
    tracing_config: Dict = None,
    revision_id: str = None,
    layers: List = None,
    file_system_configs: List = None,
    image_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modify the version-specific settings of a Lambda function. When you update a function, Lambda provisions an instance of the function and its supporting resources. If your function connects to a VPC, this process can take a minute. During this time, you can't modify the function, but you can still invoke it. The LastUpdateStatus, LastUpdateStatusReason, and LastUpdateStatusReasonCode fields in the response from GetFunctionConfiguration indicate when the update is complete and the function is processing events with the new configuration. For more information, see Function States. These settings can vary between versions of a function and are locked when you publish a version. You can't modify the configuration of a published version, only the unpublished version. To configure function concurrency, use PutFunctionConcurrency. To grant invoke permissions to an account or Amazon Web Services service, use AddPermission.

    Args:
        function_name(str): The name of the Lambda function.  Name formats     Function name - my-function.    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.    Partial ARN - 123456789012:function:my-function.   The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
        role(str, optional): The Amazon Resource Name (ARN) of the function's execution role. Defaults to None.
        handler(str, optional): The name of the method within your code that Lambda calls to execute your function. The format includes the file name. It can also include namespaces and other qualifiers, depending on the runtime. For more information, see Programming Model. Defaults to None.
        description(str, optional): A description of the function. Defaults to None.
        timeout(int, optional): The amount of time that Lambda allows a function to run before stopping it. The default is 3 seconds. The maximum allowed value is 900 seconds. For additional information, see Lambda execution environment. Defaults to None.
        memory_size(int, optional): The amount of memory available to the function at runtime. Increasing the function memory also increases its CPU allocation. The default value is 128 MB. The value can be any multiple of 1 MB. Defaults to None.
        vpc_config(Dict, optional): For network connectivity to Amazon Web Services resources in a VPC, specify a list of security groups and subnets in the VPC. When you connect a function to a VPC, it can only access resources and the internet through that VPC. For more information, see VPC Settings. Defaults to None.
        environment(Dict, optional): Environment variables that are accessible from function code during execution. Defaults to None.
        runtime(str, optional): The identifier of the function's runtime. Defaults to None.
        dead_letter_config(Dict, optional): A dead letter queue configuration that specifies the queue or topic where Lambda sends asynchronous events when they fail processing. For more information, see Dead Letter Queues. Defaults to None.
        kms_key_arn(str, optional): The ARN of the Amazon Web Services Key Management Service (KMS) key that's used to encrypt your function's environment variables. If it's not provided, Lambda uses a default service key. Defaults to None.
        tracing_config(Dict, optional): Set Mode to Active to sample and trace a subset of incoming requests with X-Ray. Defaults to None.
        revision_id(str, optional): Only update the function if the revision ID matches the ID that's specified. Use this option to avoid modifying a function that has changed since you last read it. Defaults to None.
        layers(List, optional): A list of function layers to add to the function's execution environment. Specify each layer by its ARN, including the version. Defaults to None.
        file_system_configs(List, optional): Connection settings for an Amazon EFS file system. Defaults to None.
        image_config(Dict, optional):  Container image configuration values that override the values in the container image Dockerfile. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.function.configuration.update(ctx, function_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.function.configuration.update function_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="update_function_configuration",
        op_kwargs={
            "FunctionName": function_name,
            "Role": role,
            "Handler": handler,
            "Description": description,
            "Timeout": timeout,
            "MemorySize": memory_size,
            "VpcConfig": vpc_config,
            "Environment": environment,
            "Runtime": runtime,
            "DeadLetterConfig": dead_letter_config,
            "KMSKeyArn": kms_key_arn,
            "TracingConfig": tracing_config,
            "RevisionId": revision_id,
            "Layers": layers,
            "FileSystemConfigs": file_system_configs,
            "ImageConfig": image_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Gets the indexing configuration.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.indexing_configuration.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.indexing_configuration.get
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="iot", operation="get_indexing_configuration", op_kwargs={}
    )


async def update(
    hub,
    ctx,
    thing_indexing_configuration: Dict = None,
    thing_group_indexing_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the search configuration.

    Args:
        thing_indexing_configuration(Dict, optional): Thing indexing configuration. Defaults to None.
        thing_group_indexing_configuration(Dict, optional): Thing group indexing configuration. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.indexing_configuration.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.indexing_configuration.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="update_indexing_configuration",
        op_kwargs={
            "thingIndexingConfiguration": thing_indexing_configuration,
            "thingGroupIndexingConfiguration": thing_group_indexing_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, email_identity: str, policy_name: str, policy: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates the specified sending authorization policy for the given identity (an email address or a domain).  This API is for the identity owner only. If you have not verified the identity, this API will return an error.  Sending authorization is a feature that enables an identity owner to authorize other senders to use its identities. For information about using sending authorization, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        email_identity(str): The email identity for which you want to create a policy.
        policy_name(str): The name of the policy. The policy name cannot exceed 64 characters and can only include alphanumeric characters, dashes, and underscores.
        policy(str): The text of the policy in JSON format. The policy cannot exceed 4 KB. For information about the syntax of sending authorization policies, see the Amazon SES Developer Guide.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.email.identity.policy.create(
                ctx, email_identity=value, policy_name=value, policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.email.identity.policy.create email_identity=value, policy_name=value, policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="create_email_identity_policy",
        op_kwargs={
            "EmailIdentity": email_identity,
            "PolicyName": policy_name,
            "Policy": policy,
        },
    )


async def delete(hub, ctx, email_identity: str, policy_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified sending authorization policy for the given identity (an email address or a domain). This API returns successfully even if a policy with the specified name does not exist.  This API is for the identity owner only. If you have not verified the identity, this API will return an error.  Sending authorization is a feature that enables an identity owner to authorize other senders to use its identities. For information about using sending authorization, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        email_identity(str): The email identity for which you want to delete a policy.
        policy_name(str): The name of the policy. The policy name cannot exceed 64 characters and can only include alphanumeric characters, dashes, and underscores.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.email.identity.policy.delete(
                ctx, email_identity=value, policy_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.email.identity.policy.delete email_identity=value, policy_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="delete_email_identity_policy",
        op_kwargs={"EmailIdentity": email_identity, "PolicyName": policy_name},
    )


async def get_all(hub, ctx, email_identity: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the requested sending authorization policies for the given identity (an email address or a domain). The policies are returned as a map of policy names to policy contents. You can retrieve a maximum of 20 policies at a time.  This API is for the identity owner only. If you have not verified the identity, this API will return an error.  Sending authorization is a feature that enables an identity owner to authorize other senders to use its identities. For information about using sending authorization, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        email_identity(str): The email identity that you want to retrieve policies for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.email.identity.policy.get_all(ctx, email_identity=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.email.identity.policy.get_all email_identity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="get_email_identity_policies",
        op_kwargs={"EmailIdentity": email_identity},
    )


async def update(hub, ctx, email_identity: str, policy_name: str, policy: str) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified sending authorization policy for the given identity (an email address or a domain). This API returns successfully even if a policy with the specified name does not exist.  This API is for the identity owner only. If you have not verified the identity, this API will return an error.  Sending authorization is a feature that enables an identity owner to authorize other senders to use its identities. For information about using sending authorization, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        email_identity(str): The email identity for which you want to update policy.
        policy_name(str): The name of the policy. The policy name cannot exceed 64 characters and can only include alphanumeric characters, dashes, and underscores.
        policy(str): The text of the policy in JSON format. The policy cannot exceed 4 KB.  For information about the syntax of sending authorization policies, see the Amazon SES Developer Guide.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.email.identity.policy.update(
                ctx, email_identity=value, policy_name=value, policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.email.identity.policy.update email_identity=value, policy_name=value, policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="update_email_identity_policy",
        op_kwargs={
            "EmailIdentity": email_identity,
            "PolicyName": policy_name,
            "Policy": policy,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def list_all(
    hub, ctx, filters: List = None, max_records: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the platform branches available for your account in an AWS Region. Provides summary information about each platform branch. For definitions of platform branch and other platform-related terms, see AWS Elastic Beanstalk Platforms Glossary.

    Args:
        filters(List, optional): Criteria for restricting the resulting list of platform branches. The filter is evaluated as a logical conjunction (AND) of the separate SearchFilter terms. The following list shows valid attribute values for each of the SearchFilter terms. Most operators take a single value. The in and not_in operators can take multiple values.    Attribute = BranchName:    Operator: = | != | begins_with | ends_with | contains | in | not_in       Attribute = LifecycleState:    Operator: = | != | in | not_in     Values: beta | supported | deprecated | retired       Attribute = PlatformName:    Operator: = | != | begins_with | ends_with | contains | in | not_in       Attribute = TierType:    Operator: = | !=     Values: WebServer/Standard | Worker/SQS/HTTP      Array size: limited to 10 SearchFilter objects. Within each SearchFilter item, the Values array is limited to 10 items. Defaults to None.
        max_records(int, optional): The maximum number of platform branch values returned in one call. Defaults to None.
        next_token(str, optional): For a paginated request. Specify a token from a previous response page to retrieve the next response page. All other parameter values must be identical to the ones specified in the initial request. If no NextToken is specified, the first page is retrieved. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.platform.branch.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.platform.branch.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="list_platform_branches",
        op_kwargs={
            "Filters": filters,
            "MaxRecords": max_records,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def accept(
    hub, ctx, transit_gateway_attachment_id: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Accepts a transit gateway peering attachment request. The peering attachment must be in the pendingAcceptance state.

    Args:
        transit_gateway_attachment_id(str): The ID of the transit gateway attachment.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.peering_attachment.accept(
                ctx, transit_gateway_attachment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.peering_attachment.accept transit_gateway_attachment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="accept_transit_gateway_peering_attachment",
        op_kwargs={
            "TransitGatewayAttachmentId": transit_gateway_attachment_id,
            "DryRun": dry_run,
        },
    )


async def create(
    hub,
    ctx,
    transit_gateway_id: str,
    peer_transit_gateway_id: str,
    peer_account_id: str,
    peer_region: str,
    tag_specifications: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Requests a transit gateway peering attachment between the specified transit gateway (requester) and a peer transit gateway (accepter). The transit gateways must be in different Regions. The peer transit gateway can be in your account or a different AWS account.  After you create the peering attachment, the owner of the accepter transit gateway must accept the attachment request.

    Args:
        transit_gateway_id(str): The ID of the transit gateway.
        peer_transit_gateway_id(str): The ID of the peer transit gateway with which to create the peering attachment.
        peer_account_id(str): The AWS account ID of the owner of the peer transit gateway.
        peer_region(str): The Region where the peer transit gateway is located.
        tag_specifications(List, optional): The tags to apply to the transit gateway peering attachment. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.peering_attachment.create(
                ctx,
                transit_gateway_id=value,
                peer_transit_gateway_id=value,
                peer_account_id=value,
                peer_region=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.peering_attachment.create transit_gateway_id=value, peer_transit_gateway_id=value, peer_account_id=value, peer_region=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_transit_gateway_peering_attachment",
        op_kwargs={
            "TransitGatewayId": transit_gateway_id,
            "PeerTransitGatewayId": peer_transit_gateway_id,
            "PeerAccountId": peer_account_id,
            "PeerRegion": peer_region,
            "TagSpecifications": tag_specifications,
            "DryRun": dry_run,
        },
    )


async def delete(
    hub, ctx, transit_gateway_attachment_id: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a transit gateway peering attachment.

    Args:
        transit_gateway_attachment_id(str): The ID of the transit gateway peering attachment.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.peering_attachment.delete(
                ctx, transit_gateway_attachment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.peering_attachment.delete transit_gateway_attachment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_transit_gateway_peering_attachment",
        op_kwargs={
            "TransitGatewayAttachmentId": transit_gateway_attachment_id,
            "DryRun": dry_run,
        },
    )


async def describe_all(
    hub,
    ctx,
    transit_gateway_attachment_ids: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes your transit gateway peering attachments.

    Args:
        transit_gateway_attachment_ids(List, optional): One or more IDs of the transit gateway peering attachments. Defaults to None.
        filters(List, optional): One or more filters. The possible values are:    transit-gateway-attachment-id - The ID of the transit gateway attachment.    local-owner-id - The ID of your AWS account.    remote-owner-id - The ID of the AWS account in the remote Region that owns the transit gateway.    state - The state of the peering attachment. Valid values are available | deleted | deleting | failed | failing | initiatingRequest | modifying | pendingAcceptance | pending | rollingBack | rejected | rejecting).    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources that have a tag with a specific key, regardless of the tag value.    transit-gateway-id - The ID of the transit gateway.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.peering_attachment.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.peering_attachment.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_transit_gateway_peering_attachments",
        op_kwargs={
            "TransitGatewayAttachmentIds": transit_gateway_attachment_ids,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
            "DryRun": dry_run,
        },
    )


async def reject(
    hub, ctx, transit_gateway_attachment_id: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Rejects a transit gateway peering attachment request.

    Args:
        transit_gateway_attachment_id(str): The ID of the transit gateway peering attachment.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.peering_attachment.reject(
                ctx, transit_gateway_attachment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.peering_attachment.reject transit_gateway_attachment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="reject_transit_gateway_peering_attachment",
        op_kwargs={
            "TransitGatewayAttachmentId": transit_gateway_attachment_id,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    role_arn: str,
    edition: str = None,
    server_side_encryption_configuration: Dict = None,
    description: str = None,
    client_token: str = None,
    tags: List = None,
    user_token_configurations: List = None,
    user_context_policy: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new Amazon Kendra index. Index creation is an asynchronous operation. To determine if index creation has completed, check the Status field returned from a call to DescribeIndex. The Status field is set to ACTIVE when the index is ready to use. Once the index is active you can index your documents using the BatchPutDocument operation or using one of the supported data sources.

    Args:
        name(str): The name for the new index.
        edition(str, optional): The Amazon Kendra edition to use for the index. Choose DEVELOPER_EDITION for indexes intended for development, testing, or proof of concept. Use ENTERPRISE_EDITION for your production databases. Once you set the edition for an index, it can't be changed. The Edition parameter is optional. If you don't supply a value, the default is ENTERPRISE_EDITION. For more information on quota limits for enterprise and developer editions, see Quotas. Defaults to None.
        role_arn(str): An Identity and Access Management(IAM) role that gives Amazon Kendra permissions to access your Amazon CloudWatch logs and metrics. This is also the role used when you use the BatchPutDocument operation to index documents from an Amazon S3 bucket.
        server_side_encryption_configuration(Dict, optional): The identifier of the KMScustomer managed key (CMK) to use to encrypt data indexed by Amazon Kendra. Amazon Kendra doesn't support asymmetric CMKs. Defaults to None.
        description(str, optional): A description for the index. Defaults to None.
        client_token(str, optional): A token that you provide to identify the request to create an index. Multiple calls to the CreateIndex operation with the same client token will create only one index. Defaults to None.
        tags(List, optional): A list of key-value pairs that identify the index. You can use the tags to identify and organize your resources and to control access to resources. Defaults to None.
        user_token_configurations(List, optional): The user token configuration. Defaults to None.
        user_context_policy(str, optional): The user context policy.  ATTRIBUTE_FILTER  All indexed content is searchable and displayable for all users. If there is an access control list, it is ignored. You can filter on user and group attributes.   USER_TOKEN  Enables SSO and token-based user access control. All documents with no access control and all documents accessible to the user will be searchable and displayable.   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.index.create(ctx, name=value, role_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.index.create name=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="create_index",
        op_kwargs={
            "Name": name,
            "Edition": edition,
            "RoleArn": role_arn,
            "ServerSideEncryptionConfiguration": server_side_encryption_configuration,
            "Description": description,
            "ClientToken": client_token,
            "Tags": tags,
            "UserTokenConfigurations": user_token_configurations,
            "UserContextPolicy": user_context_policy,
        },
    )


async def delete(hub, ctx, id_: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an existing Amazon Kendra index. An exception is not thrown if the index is already being deleted. While the index is being deleted, the Status field returned by a call to the DescribeIndex operation is set to DELETING.

    Args:
        id_(str): The identifier of the index to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.index.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.index.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="kendra", operation="delete_index", op_kwargs={"Id": id_}
    )


async def describe(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes an existing Amazon Kendra index

    Args:
        id_(str): The name of the index to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.index.describe(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.index.describe id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="kendra", operation="describe_index", op_kwargs={"Id": id_}
    )


async def update(
    hub,
    ctx,
    id_: str,
    name: str = None,
    role_arn: str = None,
    description: str = None,
    document_metadata_configuration_updates: List = None,
    capacity_units: Dict = None,
    user_token_configurations: List = None,
    user_context_policy: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Updates an existing Amazon Kendra index.

    Args:
        id_(str): The identifier of the index to update.
        name(str, optional): The name of the index to update. Defaults to None.
        role_arn(str, optional): A new IAM role that gives Amazon Kendra permission to access your Amazon CloudWatch logs. Defaults to None.
        description(str, optional): A new description for the index. Defaults to None.
        document_metadata_configuration_updates(List, optional): The document metadata to update. . Defaults to None.
        capacity_units(Dict, optional): Sets the number of additional storage and query capacity units that should be used by the index. You can change the capacity of the index up to 5 times per day. If you are using extra storage units, you can't reduce the storage capacity below that required to meet the storage needs for your index. Defaults to None.
        user_token_configurations(List, optional): The user token configuration. Defaults to None.
        user_context_policy(str, optional): The user user token context policy. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.index.update(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.index.update id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="update_index",
        op_kwargs={
            "Id": id_,
            "Name": name,
            "RoleArn": role_arn,
            "Description": description,
            "DocumentMetadataConfigurationUpdates": document_metadata_configuration_updates,
            "CapacityUnits": capacity_units,
            "UserTokenConfigurations": user_token_configurations,
            "UserContextPolicy": user_context_policy,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    authentication_token: str = None,
    start_time: str = None,
    end_time: str = None,
    organization_id: str = None,
    activity_types: str = None,
    resource_id: str = None,
    user_id: str = None,
    include_indirect_activities: bool = None,
    limit: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the user activities in a specified time period.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        start_time(str, optional): The timestamp that determines the starting time of the activities. The response includes the activities performed after the specified timestamp. Defaults to None.
        end_time(str, optional): The timestamp that determines the end time of the activities. The response includes the activities performed before the specified timestamp. Defaults to None.
        organization_id(str, optional): The ID of the organization. This is a mandatory parameter when using administrative API (SigV4) requests. Defaults to None.
        activity_types(str, optional): Specifies which activity types to include in the response. If this field is left empty, all activity types are returned. Defaults to None.
        resource_id(str, optional): The document or folder ID for which to describe activity types. Defaults to None.
        user_id(str, optional): The ID of the user who performed the action. The response includes activities pertaining to this user. This is an optional parameter and is only applicable for administrative API (SigV4) requests. Defaults to None.
        include_indirect_activities(bool, optional): Includes indirect activities. An indirect activity results from a direct activity performed on a parent resource. For example, sharing a parent folder (the direct activity) shares all of the subfolders and documents within the parent folder (the indirect activity). Defaults to None.
        limit(int, optional): The maximum number of items to return. Defaults to None.
        marker(str, optional): The marker for the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.activity.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.activity.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="describe_activities",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "StartTime": start_time,
            "EndTime": end_time,
            "OrganizationId": organization_id,
            "ActivityTypes": activity_types,
            "ResourceId": resource_id,
            "UserId": user_id,
            "IncludeIndirectActivities": include_indirect_activities,
            "Limit": limit,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub, ctx, instance_arn: str, stat: str, period: int, start_time: str, end_time: str
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the projected utilization metrics of Amazon EC2 instance recommendations.  The Cpu and Memory metrics are the only projected utilization metrics returned when you run this action. Additionally, the Memory metric is returned only for resources that have the unified CloudWatch agent installed on them. For more information, see Enabling Memory Utilization with the CloudWatch Agent.

    Args:
        instance_arn(str): The Amazon Resource Name (ARN) of the instances for which to return recommendation projected metrics.
        stat(str): The statistic of the projected metrics.
        period(int): The granularity, in seconds, of the projected metrics data points.
        start_time(str): The time stamp of the first projected metrics data point to return.
        end_time(str): The time stamp of the last projected metrics data point to return.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.compute_optimizer.ec2.recommendation_projected_metric.get_all(
                ctx, instance_arn=value, stat=value, period=value, start_time=value, end_time=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.compute_optimizer.ec2.recommendation_projected_metric.get_all instance_arn=value, stat=value, period=value, start_time=value, end_time=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="compute-optimizer",
        operation="get_ec2_recommendation_projected_metrics",
        op_kwargs={
            "instanceArn": instance_arn,
            "stat": stat,
            "period": period,
            "startTime": start_time,
            "endTime": end_time,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def remove(
    hub, ctx, db_instance_identifier: str, role_arn: str, feature_name: str
) -> None:
    r"""
    **Autogenerated function**

    Disassociates an Amazon Web Services Identity and Access Management (IAM) role from a DB instance.

    Args:
        db_instance_identifier(str): The name of the DB instance to disassociate the IAM role from.
        role_arn(str): The Amazon Resource Name (ARN) of the IAM role to disassociate from the DB instance, for example, arn:aws:iam::123456789012:role/AccessRole.
        feature_name(str): The name of the feature for the DB instance that the IAM role is to be disassociated from. For the list of supported feature names, see DBEngineVersion. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.role.from_db.instance.remove(
                ctx, db_instance_identifier=value, role_arn=value, feature_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.role.from_db.instance.remove db_instance_identifier=value, role_arn=value, feature_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="remove_role_from_db_instance",
        op_kwargs={
            "DBInstanceIdentifier": db_instance_identifier,
            "RoleArn": role_arn,
            "FeatureName": feature_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def clear(hub, ctx, index_id: str) -> None:
    r"""
    **Autogenerated function**

    Clears existing query suggestions from an index. This deletes existing suggestions only, not the queries in the query log. After you clear suggestions, Amazon Kendra learns new suggestions based on new queries added to the query log from the time you cleared suggestions. If you do not see any new suggestions, then please allow Amazon Kendra to collect enough queries to learn new suggestions.

    Args:
        index_id(str): The identifier of the index you want to clear query suggestions from.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.query_suggestion.init.clear(ctx, index_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.query_suggestion.init.clear index_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="clear_query_suggestions",
        op_kwargs={"IndexId": index_id},
    )


async def get_all(
    hub, ctx, index_id: str, query_text: str, max_suggestions_count: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Fetches the queries that are suggested to your users.

    Args:
        index_id(str): The identifier of the index you want to get query suggestions from.
        query_text(str): The text of a user's query to generate query suggestions. A query is suggested if the query prefix matches what a user starts to type as their query. Amazon Kendra does not show any suggestions if a user types fewer than two characters or more than 60 characters. A query must also have at least one search result and contain at least one word of more than four characters.
        max_suggestions_count(int, optional): The maximum number of query suggestions you want to show to your users. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.query_suggestion.init.get_all(
                ctx, index_id=value, query_text=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.query_suggestion.init.get_all index_id=value, query_text=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="get_query_suggestions",
        op_kwargs={
            "IndexId": index_id,
            "QueryText": query_text,
            "MaxSuggestionsCount": max_suggestions_count,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    name: str = None,
    region: str = None,
    contents: bytes = None,
    snapshot_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Creates an AWS Mobile Hub project.

    Args:
        name(str, optional):  Name of the project. . Defaults to None.
        region(str, optional):  Default region where project resources should be created. . Defaults to None.
        contents(bytes, optional):  ZIP or YAML file which contains configuration settings to be used when creating the project. This may be the contents of the file downloaded from the URL provided in an export project operation. . Defaults to None.
        snapshot_id(str, optional):  Unique identifier for an exported snapshot of project configuration. This snapshot identifier is included in the share URL when a project is exported. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mobile.project.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mobile.project.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mobile",
        operation="create_project",
        op_kwargs={
            "name": name,
            "region": region,
            "contents": contents,
            "snapshotId": snapshot_id,
        },
    )


async def delete(hub, ctx, project_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Delets a project in AWS Mobile Hub.

    Args:
        project_id(str):  Unique project identifier. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mobile.project.delete(ctx, project_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mobile.project.delete project_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mobile",
        operation="delete_project",
        op_kwargs={"projectId": project_id},
    )


async def describe(hub, ctx, project_id: str, sync_from_resources: bool = None) -> Dict:
    r"""
    **Autogenerated function**

     Gets details about a project in AWS Mobile Hub.

    Args:
        project_id(str):  Unique project identifier. .
        sync_from_resources(bool, optional):  If set to true, causes AWS Mobile Hub to synchronize information from other services, e.g., update state of AWS CloudFormation stacks in the AWS Mobile Hub project. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mobile.project.describe(ctx, project_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mobile.project.describe project_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mobile",
        operation="describe_project",
        op_kwargs={"projectId": project_id, "syncFromResources": sync_from_resources},
    )


async def export(hub, ctx, project_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Exports project configuration to a snapshot which can be downloaded and shared. Note that mobile app push credentials are encrypted in exported projects, so they can only be shared successfully within the same AWS account.

    Args:
        project_id(str):  Unique project identifier. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mobile.project.export(ctx, project_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mobile.project.export project_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mobile",
        operation="export_project",
        op_kwargs={"projectId": project_id},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

     Lists projects in AWS Mobile Hub.

    Args:
        max_results(int, optional):  Maximum number of records to list in a single response. . Defaults to None.
        next_token(str, optional):  Pagination token. Set to null to start listing projects from start. If non-null pagination token is returned in a result, then pass its value in here in another request to list more projects. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mobile.project.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mobile.project.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mobile",
        operation="list_projects",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )


async def update(hub, ctx, project_id: str, contents: bytes = None) -> Dict:
    r"""
    **Autogenerated function**

     Update an existing project.

    Args:
        contents(bytes, optional):  ZIP or YAML file which contains project configuration to be updated. This should be the contents of the file downloaded from the URL provided in an export project operation. . Defaults to None.
        project_id(str):  Unique project identifier. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mobile.project.update(ctx, project_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mobile.project.update project_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mobile",
        operation="update_project",
        op_kwargs={"contents": contents, "projectId": project_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, cluster_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Fetches the attached managed scaling policy for an Amazon EMR cluster.

    Args:
        cluster_id(str): Specifies the ID of the cluster for which the managed scaling policy will be fetched. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.managed_scaling_policy.get(ctx, cluster_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.managed_scaling_policy.get cluster_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="get_managed_scaling_policy",
        op_kwargs={"ClusterId": cluster_id},
    )


async def put(hub, ctx, cluster_id: str, managed_scaling_policy: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates a managed scaling policy for an Amazon EMR cluster. The managed scaling policy defines the limits for resources, such as EC2 instances that can be added or terminated from a cluster. The policy only applies to the core and task nodes. The master node cannot be scaled after initial configuration.

    Args:
        cluster_id(str): Specifies the ID of an EMR cluster where the managed scaling policy is attached. .
        managed_scaling_policy(Dict): Specifies the constraints for the managed scaling policy. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.managed_scaling_policy.put(
                ctx, cluster_id=value, managed_scaling_policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.managed_scaling_policy.put cluster_id=value, managed_scaling_policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="put_managed_scaling_policy",
        op_kwargs={
            "ClusterId": cluster_id,
            "ManagedScalingPolicy": managed_scaling_policy,
        },
    )


async def remove(hub, ctx, cluster_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Removes a managed scaling policy from a specified EMR cluster.

    Args:
        cluster_id(str):  Specifies the ID of the cluster from which the managed scaling policy will be removed. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.managed_scaling_policy.remove(ctx, cluster_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.managed_scaling_policy.remove cluster_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="remove_managed_scaling_policy",
        op_kwargs={"ClusterId": cluster_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def create(
    hub,
    ctx,
    sync_name: str,
    s3_destination: Dict = None,
    sync_type: str = None,
    sync_source: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    A resource data sync helps you view data from multiple sources in a single location. Amazon Web Services Systems Manager offers two types of resource data sync: SyncToDestination and SyncFromSource. You can configure Systems Manager Inventory to use the SyncToDestination type to synchronize Inventory data from multiple Regions to a single Amazon Simple Storage Service (Amazon S3) bucket. For more information, see Configuring resource data sync for Inventory in the Amazon Web Services Systems Manager User Guide. You can configure Systems Manager Explorer to use the SyncFromSource type to synchronize operational work items (OpsItems) and operational data (OpsData) from multiple Regions to a single Amazon S3 bucket. This type can synchronize OpsItems and OpsData from multiple accounts and Regions or EntireOrganization by using Organizations. For more information, see Setting up Systems Manager Explorer to display data from multiple accounts and Regions in the Amazon Web Services Systems Manager User Guide. A resource data sync is an asynchronous operation that returns immediately. After a successful initial sync is completed, the system continuously syncs data. To check the status of a sync, use the ListResourceDataSync.  By default, data isn't encrypted in Amazon S3. We strongly recommend that you enable encryption in Amazon S3 to ensure secure data storage. We also recommend that you secure access to the Amazon S3 bucket by creating a restrictive bucket policy.

    Args:
        sync_name(str): A name for the configuration.
        s3_destination(Dict, optional): Amazon S3 configuration details for the sync. This parameter is required if the SyncType value is SyncToDestination. Defaults to None.
        sync_type(str, optional): Specify SyncToDestination to create a resource data sync that synchronizes data to an S3 bucket for Inventory. If you specify SyncToDestination, you must provide a value for S3Destination. Specify SyncFromSource to synchronize data from a single account and multiple Regions, or multiple accounts and Regions, as listed in Organizations for Explorer. If you specify SyncFromSource, you must provide a value for SyncSource. The default value is SyncToDestination. Defaults to None.
        sync_source(Dict, optional): Specify information about the data sources to synchronize. This parameter is required if the SyncType value is SyncFromSource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.resource.data_sync.create(ctx, sync_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.resource.data_sync.create sync_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="create_resource_data_sync",
        op_kwargs={
            "SyncName": sync_name,
            "S3Destination": s3_destination,
            "SyncType": sync_type,
            "SyncSource": sync_source,
        },
    )


async def delete(hub, ctx, sync_name: str, sync_type: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a resource data sync configuration. After the configuration is deleted, changes to data on managed instances are no longer synced to or from the target. Deleting a sync configuration doesn't delete data.

    Args:
        sync_name(str): The name of the configuration to delete.
        sync_type(str, optional): Specify the type of resource data sync to delete. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.resource.data_sync.delete(ctx, sync_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.resource.data_sync.delete sync_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="delete_resource_data_sync",
        op_kwargs={"SyncName": sync_name, "SyncType": sync_type},
    )


async def list_(
    hub, ctx, sync_type: str = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists your resource data sync configurations. Includes information about the last time a sync attempted to start, the last sync status, and the last time a sync successfully completed. The number of sync configurations might be too large to return using a single call to ListResourceDataSync. You can limit the number of sync configurations returned by using the MaxResults parameter. To determine whether there are more sync configurations to list, check the value of NextToken in the output. If there are more sync configurations to list, you can request them by specifying the NextToken returned in the call to the parameter of a subsequent call.

    Args:
        sync_type(str, optional): View a list of resource data syncs according to the sync type. Specify SyncToDestination to view resource data syncs that synchronize data to an Amazon S3 bucket. Specify SyncFromSource to view resource data syncs from Organizations or from multiple Regions. Defaults to None.
        next_token(str, optional): A token to start the list. Use this token to get the next set of results. . Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.resource.data_sync.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.resource.data_sync.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="list_resource_data_sync",
        op_kwargs={
            "SyncType": sync_type,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(hub, ctx, sync_name: str, sync_type: str, sync_source: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Update a resource data sync. After you create a resource data sync for a Region, you can't change the account options for that sync. For example, if you create a sync in the us-east-2 (Ohio) Region and you choose the Include only the current account option, you can't edit that sync later and choose the Include all accounts from my Organizations configuration option. Instead, you must delete the first resource data sync, and create a new one.  This API operation only supports a resource data sync that was created with a SyncFromSource SyncType.

    Args:
        sync_name(str): The name of the resource data sync you want to update.
        sync_type(str): The type of resource data sync. The supported SyncType is SyncFromSource.
        sync_source(Dict): Specify information about the data sources to synchronize.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.resource.data_sync.update(
                ctx, sync_name=value, sync_type=value, sync_source=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.resource.data_sync.update sync_name=value, sync_type=value, sync_source=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="update_resource_data_sync",
        op_kwargs={
            "SyncName": sync_name,
            "SyncType": sync_type,
            "SyncSource": sync_source,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    detector_id: str,
    event_id: str,
    event_type_name: str,
    entities: List,
    event_timestamp: str,
    event_variables: Dict,
    detector_version_id: str = None,
    external_model_endpoint_data_blobs: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Evaluates an event against a detector version. If a version ID is not provided, the detector’s (ACTIVE) version is used.

    Args:
        detector_id(str): The detector ID.
        detector_version_id(str, optional): The detector version ID. Defaults to None.
        event_id(str): The unique ID used to identify the event.
        event_type_name(str): The event type associated with the detector specified for the prediction.
        entities(List): The entity type (associated with the detector's event type) and specific entity ID representing who performed the event. If an entity id is not available, use "UNKNOWN.".
        event_timestamp(str): Timestamp that defines when the event under evaluation occurred.
        event_variables(Dict): Names of the event type's variables you defined in Amazon Fraud Detector to represent data elements and their corresponding values for the event you are sending for evaluation.    You must provide at least one eventVariable   If detectorVersion is associated with a modelVersion, you must provide at least one associated eventVariable    To ensure highest possible fraud prediction and to simplify your data preparation, Amazon Fraud Detector will replace all missing variables or values as follows:  For Amazon Fraud Detector trained models:  If a null value is provided explicitly for a variable or if a variable is missing, model will replace the null value or the missing variable (no variable name in the eventVariables map) with calculated default mean/medians for numeric variables and with special values for categorical variables.  For External models ( for example, imported SageMaker):  If a null value is provided explicitly for a variable, the model and rules will use “null” as the value. If a variable is not provided (no variable name in the eventVariables map), model and rules will use the default value that is provided for the variable. .
        external_model_endpoint_data_blobs(Dict, optional): The Amazon SageMaker model endpoint input data blobs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.event.prediction.get(
                ctx,
                detector_id=value,
                event_id=value,
                event_type_name=value,
                entities=value,
                event_timestamp=value,
                event_variables=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.event.prediction.get detector_id=value, event_id=value, event_type_name=value, entities=value, event_timestamp=value, event_variables=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="get_event_prediction",
        op_kwargs={
            "detectorId": detector_id,
            "detectorVersionId": detector_version_id,
            "eventId": event_id,
            "eventTypeName": event_type_name,
            "entities": entities,
            "eventTimestamp": event_timestamp,
            "eventVariables": event_variables,
            "externalModelEndpointDataBlobs": external_model_endpoint_data_blobs,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def register(
    hub, ctx, identity_pool_id: str, identity_id: str, platform: str, token: str
) -> Dict:
    r"""
    **Autogenerated function**

    Registers a device to receive push sync notifications.This API can only be called with temporary credentials provided by Cognito Identity. You cannot call this API with developer credentials.

    Args:
        identity_pool_id(str): A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. Here, the ID of the pool that the identity belongs to.
        identity_id(str): The unique ID for this identity.
        platform(str): The SNS platform type (e.g. GCM, SDM, APNS, APNS_SANDBOX).
        token(str): The push token.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_sync.device.register(
                ctx, identity_pool_id=value, identity_id=value, platform=value, token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_sync.device.register identity_pool_id=value, identity_id=value, platform=value, token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-sync",
        operation="register_device",
        op_kwargs={
            "IdentityPoolId": identity_pool_id,
            "IdentityId": identity_id,
            "Platform": platform,
            "Token": token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    client_token: str,
    job_type: str,
    name: str,
    s3_job_definition: Dict,
    custom_data_identifier_ids: List = None,
    description: str = None,
    initial_run: bool = None,
    sampling_percentage: int = None,
    schedule_frequency: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Creates and defines the settings for a classification job.

    Args:
        client_token(str): A unique, case-sensitive token that you provide to ensure the idempotency of the request.
        custom_data_identifier_ids(List, optional): The custom data identifiers to use for data analysis and classification. Defaults to None.
        description(str, optional): A custom description of the job. The description can contain as many as 200 characters. Defaults to None.
        initial_run(bool, optional): Specifies whether to analyze all existing, eligible objects immediately after the job is created. Defaults to None.
        job_type(str): The schedule for running the job. Valid values are: ONE_TIME - Run the job only once. If you specify this value, don't specify a value for the scheduleFrequency property. SCHEDULED - Run the job on a daily, weekly, or monthly basis. If you specify this value, use the scheduleFrequency property to define the recurrence pattern for the job.
        name(str): A custom name for the job. The name can contain as many as 500 characters.
        s3_job_definition(Dict): The S3 buckets that contain the objects to analyze, and the scope of that analysis.
        sampling_percentage(int, optional): The sampling depth, as a percentage, to apply when processing objects. This value determines the percentage of eligible objects that the job analyzes. If this value is less than 100, Amazon Macie selects the objects to analyze at random, up to the specified percentage, and analyzes all the data in those objects. Defaults to None.
        schedule_frequency(Dict, optional): The recurrence pattern for running the job. To run the job only once, don't specify a value for this property and set the value for the jobType property to ONE_TIME. Defaults to None.
        tags(Dict, optional): A map of key-value pairs that specifies the tags to associate with the job. A job can have a maximum of 50 tags. Each tag consists of a tag key and an associated tag value. The maximum length of a tag key is 128 characters. The maximum length of a tag value is 256 characters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.classification.job.create(
                ctx, client_token=value, job_type=value, name=value, s3_job_definition=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.classification.job.create client_token=value, job_type=value, name=value, s3_job_definition=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="create_classification_job",
        op_kwargs={
            "clientToken": client_token,
            "customDataIdentifierIds": custom_data_identifier_ids,
            "description": description,
            "initialRun": initial_run,
            "jobType": job_type,
            "name": name,
            "s3JobDefinition": s3_job_definition,
            "samplingPercentage": sampling_percentage,
            "scheduleFrequency": schedule_frequency,
            "tags": tags,
        },
    )


async def describe(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the status and settings for a classification job.

    Args:
        job_id(str): The unique identifier for the classification job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.classification.job.describe(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.classification.job.describe job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="describe_classification_job",
        op_kwargs={"jobId": job_id},
    )


async def list_all(
    hub,
    ctx,
    filter_criteria: Dict = None,
    max_results: int = None,
    next_token: str = None,
    sort_criteria: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a subset of information about one or more classification jobs.

    Args:
        filter_criteria(Dict, optional): The criteria to use to filter the results. Defaults to None.
        max_results(int, optional): The maximum number of items to include in each page of the response. Defaults to None.
        next_token(str, optional): The nextToken string that specifies which page of results to return in a paginated response. Defaults to None.
        sort_criteria(Dict, optional): The criteria to use to sort the results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.classification.job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.classification.job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="list_classification_jobs",
        op_kwargs={
            "filterCriteria": filter_criteria,
            "maxResults": max_results,
            "nextToken": next_token,
            "sortCriteria": sort_criteria,
        },
    )


async def update(hub, ctx, job_id: str, job_status: str) -> Dict:
    r"""
    **Autogenerated function**

    Changes the status of a classification job.

    Args:
        job_id(str): The unique identifier for the classification job.
        job_status(str): The new status for the job. Valid values are: CANCELLED - Stops the job permanently and cancels it. This value is valid only if the job's current status is IDLE, PAUSED, RUNNING, or USER_PAUSED. If you specify this value and the job's current status is RUNNING, Amazon Macie immediately begins to stop all processing tasks for the job. You can't resume or restart a job after you cancel it. RUNNING - Resumes the job. This value is valid only if the job's current status is USER_PAUSED. If you paused the job while it was actively running and you specify this value less than 30 days after you paused the job, Macie immediately resumes processing from the point where you paused the job. Otherwise, Macie resumes the job according to the schedule and other settings for the job. USER_PAUSED - Pauses the job temporarily. This value is valid only if the job's current status is IDLE, PAUSED, or RUNNING. If you specify this value and the job's current status is RUNNING, Macie immediately begins to pause all processing tasks for the job. If you pause a one-time job and you don't resume it within 30 days, the job expires and Macie cancels the job. If you pause a recurring job when its status is RUNNING and you don't resume it within 30 days, the job run expires and Macie cancels the run. To check the expiration date, refer to the UserPausedDetails.jobExpiresAt property.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.classification.job.update(
                ctx, job_id=value, job_status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.classification.job.update job_id=value, job_status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="update_classification_job",
        op_kwargs={"jobId": job_id, "jobStatus": job_status},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, assessment_run_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Information about the data that is collected for the specified assessment run.

    Args:
        assessment_run_arn(str): The ARN that specifies the assessment run that has the telemetry data that you want to obtain.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.telemetry_metadata.get(ctx, assessment_run_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.telemetry_metadata.get assessment_run_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="get_telemetry_metadata",
        op_kwargs={"assessmentRunArn": assessment_run_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx, db_instance_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    You can call DescribeValidDBInstanceModifications to learn what modifications you can make to your DB instance. You can use this information when you call ModifyDBInstance.

    Args:
        db_instance_identifier(str): The customer identifier or the ARN of your DB instance. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.valid_db_instance_modification.describe_all(
                ctx, db_instance_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.valid_db_instance_modification.describe_all db_instance_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_valid_db_instance_modifications",
        op_kwargs={"DBInstanceIdentifier": db_instance_identifier},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def get_all(hub, ctx, topic_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns all of the properties of a topic. Topic properties returned might differ based on the authorization of the user.

    Args:
        topic_arn(str): The ARN of the topic whose properties you want to get.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.topic.attribute.get_all(ctx, topic_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.topic.attribute.get_all topic_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="get_topic_attributes",
        op_kwargs={"TopicArn": topic_arn},
    )


async def set_(
    hub, ctx, topic_arn: str, attribute_name: str, attribute_value: str = None
) -> None:
    r"""
    **Autogenerated function**

    Allows a topic owner to set an attribute of the topic to a new value.

    Args:
        topic_arn(str): The ARN of the topic to modify.
        attribute_name(str): A map of attributes with their corresponding values. The following lists the names, descriptions, and values of the special request parameters that the SetTopicAttributes action uses:    DeliveryPolicy – The policy that defines how Amazon SNS retries failed deliveries to HTTP/S endpoints.    DisplayName – The display name to use for a topic with SMS subscriptions.    Policy – The policy that defines who can access your topic. By default, only the topic owner can publish or subscribe to the topic.   The following attribute applies only to server-side-encryption:    KmsMasterKeyId – The ID of an Amazon Web Services managed customer master key (CMK) for Amazon SNS or a custom CMK. For more information, see Key Terms. For more examples, see KeyId in the Key Management Service API Reference.    The following attribute applies only to FIFO topics:    ContentBasedDeduplication – Enables content-based deduplication for FIFO topics.   By default, ContentBasedDeduplication is set to false. If you create a FIFO topic and this attribute is false, you must specify a value for the MessageDeduplicationId parameter for the Publish action.    When you set ContentBasedDeduplication to true, Amazon SNS uses a SHA-256 hash to generate the MessageDeduplicationId using the body of the message (but not the attributes of the message). (Optional) To override the generated value, you can specify a value for the MessageDeduplicationId parameter for the Publish action.    .
        attribute_value(str, optional): The new value for the attribute. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.topic.attribute.set(
                ctx, topic_arn=value, attribute_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.topic.attribute.set topic_arn=value, attribute_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="set_topic_attributes",
        op_kwargs={
            "TopicArn": topic_arn,
            "AttributeName": attribute_name,
            "AttributeValue": attribute_value,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    relational_database_name: str,
    availability_zone: str = None,
    publicly_accessible: bool = None,
    relational_database_snapshot_name: str = None,
    relational_database_bundle_id: str = None,
    source_relational_database_name: str = None,
    restore_time: str = None,
    use_latest_restorable_time: bool = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new database from an existing database snapshot in Amazon Lightsail. You can create a new database from a snapshot in if something goes wrong with your original database, or to change it to a different plan, such as a high availability or standard plan. The create relational database from snapshot operation supports tag-based access control via request tags and resource tags applied to the resource identified by relationalDatabaseSnapshotName. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        relational_database_name(str): The name to use for your new Lightsail database resource. Constraints:   Must contain from 2 to 255 alphanumeric characters, or hyphens.   The first and last character must be a letter or number.  .
        availability_zone(str, optional): The Availability Zone in which to create your new database. Use the us-east-2a case-sensitive format. You can get a list of Availability Zones by using the get regions operation. Be sure to add the include relational database Availability Zones parameter to your request. Defaults to None.
        publicly_accessible(bool, optional): Specifies the accessibility options for your new database. A value of true specifies a database that is available to resources outside of your Lightsail account. A value of false specifies a database that is available only to your Lightsail resources in the same region as your database. Defaults to None.
        relational_database_snapshot_name(str, optional): The name of the database snapshot from which to create your new database. Defaults to None.
        relational_database_bundle_id(str, optional): The bundle ID for your new database. A bundle describes the performance specifications for your database. You can get a list of database bundle IDs by using the get relational database bundles operation. When creating a new database from a snapshot, you cannot choose a bundle that is smaller than the bundle of the source database. Defaults to None.
        source_relational_database_name(str, optional): The name of the source database. Defaults to None.
        restore_time(str, optional): The date and time to restore your database from. Constraints:   Must be before the latest restorable time for the database.   Cannot be specified if the use latest restorable time parameter is true.   Specified in Coordinated Universal Time (UTC).   Specified in the Unix time format. For example, if you wish to use a restore time of October 1, 2018, at 8 PM UTC, then you input 1538424000 as the restore time.  . Defaults to None.
        use_latest_restorable_time(bool, optional): Specifies whether your database is restored from the latest backup time. A value of true restores from the latest backup time.  Default: false  Constraints: Cannot be specified if the restore time parameter is provided. Defaults to None.
        tags(List, optional): The tag keys and optional values to add to the resource during create. Use the TagResource action to tag a resource after it's created. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.relational_database.from_snapshot.create(
                ctx, relational_database_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.relational_database.from_snapshot.create relational_database_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="create_relational_database_from_snapshot",
        op_kwargs={
            "relationalDatabaseName": relational_database_name,
            "availabilityZone": availability_zone,
            "publiclyAccessible": publicly_accessible,
            "relationalDatabaseSnapshotName": relational_database_snapshot_name,
            "relationalDatabaseBundleId": relational_database_bundle_id,
            "sourceRelationalDatabaseName": source_relational_database_name,
            "restoreTime": restore_time,
            "useLatestRestorableTime": use_latest_restorable_time,
            "tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, name: str, steps: List, description: str = None, tags: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new DataBrew recipe.

    Args:
        description(str, optional): A description for the recipe. Defaults to None.
        name(str): A unique name for the recipe. Valid characters are alphanumeric (A-Z, a-z, 0-9), hyphen (-), period (.), and space.
        steps(List): An array containing the steps to be performed by the recipe. Each recipe step consists of one recipe action and (optionally) an array of condition expressions.
        tags(Dict, optional): Metadata tags to apply to this recipe. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.recipe.init.create(ctx, name=value, steps=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.recipe.init.create name=value, steps=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="create_recipe",
        op_kwargs={
            "Description": description,
            "Name": name,
            "Steps": steps,
            "Tags": tags,
        },
    )


async def describe(hub, ctx, name: str, recipe_version: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the definition of a specific DataBrew recipe corresponding to a particular version.

    Args:
        name(str): The name of the recipe to be described.
        recipe_version(str, optional): The recipe version identifier. If this parameter isn't specified, then the latest published version is returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.recipe.init.describe(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.recipe.init.describe name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="describe_recipe",
        op_kwargs={"Name": name, "RecipeVersion": recipe_version},
    )


async def list_all(
    hub,
    ctx,
    max_results: int = None,
    next_token: str = None,
    recipe_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all of the DataBrew recipes that are defined.

    Args:
        max_results(int, optional): The maximum number of results to return in this request. . Defaults to None.
        next_token(str, optional): The token returned by a previous call to retrieve the next set of results. Defaults to None.
        recipe_version(str, optional): Return only those recipes with a version identifier of LATEST_WORKING or LATEST_PUBLISHED. If RecipeVersion is omitted, ListRecipes returns all of the LATEST_PUBLISHED recipe versions. Valid values: LATEST_WORKING | LATEST_PUBLISHED . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.recipe.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.recipe.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="list_recipes",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "RecipeVersion": recipe_version,
        },
    )


async def publish(hub, ctx, name: str, description: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Publishes a new version of a DataBrew recipe.

    Args:
        description(str, optional): A description of the recipe to be published, for this version of the recipe. Defaults to None.
        name(str): The name of the recipe to be published.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.recipe.init.publish(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.recipe.init.publish name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="publish_recipe",
        op_kwargs={"Description": description, "Name": name},
    )


async def update(
    hub, ctx, name: str, description: str = None, steps: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the definition of the LATEST_WORKING version of a DataBrew recipe.

    Args:
        description(str, optional): A description of the recipe. Defaults to None.
        name(str): The name of the recipe to be updated.
        steps(List, optional): One or more steps to be performed by the recipe. Each step consists of an action, and the conditions under which the action should succeed. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.recipe.init.update(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.recipe.init.update name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="update_recipe",
        op_kwargs={"Description": description, "Name": name, "Steps": steps},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, artifact_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Returns the artifact info that corresponds to an artifact id.

    Args:
        artifact_id(str):  The unique ID for an artifact. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplify.artifact.url.get(ctx, artifact_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplify.artifact.url.get artifact_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplify",
        operation="get_artifact_url",
        op_kwargs={"artifactId": artifact_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, backup_vault_name: str, recovery_point_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a set of metadata key-value pairs that were used to create the backup.

    Args:
        backup_vault_name(str): The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the AWS Region where they are created. They consist of lowercase letters, numbers, and hyphens.
        recovery_point_arn(str): An Amazon Resource Name (ARN) that uniquely identifies a recovery point; for example, arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.recovery_point.restore_metadata.get(
                ctx, backup_vault_name=value, recovery_point_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.recovery_point.restore_metadata.get backup_vault_name=value, recovery_point_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="get_recovery_point_restore_metadata",
        op_kwargs={
            "BackupVaultName": backup_vault_name,
            "RecoveryPointArn": recovery_point_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def activate(hub, ctx, hosted_zone_id: str, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Activates a key-signing key (KSK) so that it can be used for signing by DNSSEC. This operation changes the KSK status to ACTIVE.

    Args:
        hosted_zone_id(str): A unique string used to identify a hosted zone.
        name(str): A string used to identify a key-signing key (KSK). Name can include numbers, letters, and underscores (_). Name must be unique for each key-signing key in the same hosted zone.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.key_signing_key.activate(
                ctx, hosted_zone_id=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.key_signing_key.activate hosted_zone_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="activate_key_signing_key",
        op_kwargs={"HostedZoneId": hosted_zone_id, "Name": name},
    )


async def create(
    hub,
    ctx,
    caller_reference: str,
    hosted_zone_id: str,
    key_management_service_arn: str,
    name: str,
    status: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new key-signing key (KSK) associated with a hosted zone. You can only have two KSKs per hosted zone.

    Args:
        caller_reference(str): A unique string that identifies the request.
        hosted_zone_id(str): The unique string (ID) used to identify a hosted zone.
        key_management_service_arn(str): The Amazon resource name (ARN) for a customer managed customer master key (CMK) in Key Management Service (KMS). The KeyManagementServiceArn must be unique for each key-signing key (KSK) in a single hosted zone. To see an example of KeyManagementServiceArn that grants the correct permissions for DNSSEC, scroll down to Example.  You must configure the customer managed CMK as follows:  Status  Enabled  Key spec  ECC_NIST_P256  Key usage  Sign and verify  Key policy  The key policy must give permission for the following actions:   DescribeKey   GetPublicKey   Sign   The key policy must also include the Amazon Route 53 service in the principal for your account. Specify the following:    "Service": "dnssec-route53.amazonaws.com"      For more information about working with a customer managed CMK in KMS, see Key Management Service concepts.
        name(str): A string used to identify a key-signing key (KSK). Name can include numbers, letters, and underscores (_). Name must be unique for each key-signing key in the same hosted zone.
        status(str): A string specifying the initial status of the key-signing key (KSK). You can set the value to ACTIVE or INACTIVE.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.key_signing_key.create(
                ctx,
                caller_reference=value,
                hosted_zone_id=value,
                key_management_service_arn=value,
                name=value,
                status=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.key_signing_key.create caller_reference=value, hosted_zone_id=value, key_management_service_arn=value, name=value, status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="create_key_signing_key",
        op_kwargs={
            "CallerReference": caller_reference,
            "HostedZoneId": hosted_zone_id,
            "KeyManagementServiceArn": key_management_service_arn,
            "Name": name,
            "Status": status,
        },
    )


async def deactivate(hub, ctx, hosted_zone_id: str, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deactivates a key-signing key (KSK) so that it will not be used for signing by DNSSEC. This operation changes the KSK status to INACTIVE.

    Args:
        hosted_zone_id(str): A unique string used to identify a hosted zone.
        name(str): A string used to identify a key-signing key (KSK).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.key_signing_key.deactivate(
                ctx, hosted_zone_id=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.key_signing_key.deactivate hosted_zone_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="deactivate_key_signing_key",
        op_kwargs={"HostedZoneId": hosted_zone_id, "Name": name},
    )


async def delete(hub, ctx, hosted_zone_id: str, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a key-signing key (KSK). Before you can delete a KSK, you must deactivate it. The KSK must be deactivated before you can delete it regardless of whether the hosted zone is enabled for DNSSEC signing.

    Args:
        hosted_zone_id(str): A unique string used to identify a hosted zone.
        name(str): A string used to identify a key-signing key (KSK).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.key_signing_key.delete(
                ctx, hosted_zone_id=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.key_signing_key.delete hosted_zone_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="delete_key_signing_key",
        op_kwargs={"HostedZoneId": hosted_zone_id, "Name": name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    instance_id: str,
    name: str,
    quick_connect_config: Dict,
    description: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a quick connect for the specified Amazon Connect instance.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        name(str): The name of the quick connect.
        description(str, optional): The description of the quick connect. Defaults to None.
        quick_connect_config(Dict): Configuration settings for the quick connect.
        tags(Dict, optional): One or more tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.quick_connect.init.create(
                ctx, instance_id=value, name=value, quick_connect_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.quick_connect.init.create instance_id=value, name=value, quick_connect_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="create_quick_connect",
        op_kwargs={
            "InstanceId": instance_id,
            "Name": name,
            "Description": description,
            "QuickConnectConfig": quick_connect_config,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, instance_id: str, quick_connect_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a quick connect.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        quick_connect_id(str): The identifier for the quick connect.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.quick_connect.init.delete(
                ctx, instance_id=value, quick_connect_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.quick_connect.init.delete instance_id=value, quick_connect_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="delete_quick_connect",
        op_kwargs={"InstanceId": instance_id, "QuickConnectId": quick_connect_id},
    )


async def describe(hub, ctx, instance_id: str, quick_connect_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the quick connect.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        quick_connect_id(str): The identifier for the quick connect.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.quick_connect.init.describe(
                ctx, instance_id=value, quick_connect_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.quick_connect.init.describe instance_id=value, quick_connect_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="describe_quick_connect",
        op_kwargs={"InstanceId": instance_id, "QuickConnectId": quick_connect_id},
    )


async def list_all(
    hub,
    ctx,
    instance_id: str,
    next_token: str = None,
    max_results: int = None,
    quick_connect_types: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Provides information about the quick connects for the specified Amazon Connect instance.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        next_token(str, optional): The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return per page. Defaults to None.
        quick_connect_types(List, optional): The type of quick connect. In the Amazon Connect console, when you create a quick connect, you are prompted to assign one of the following types: Agent (USER), External (PHONE_NUMBER), or Queue (QUEUE). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.quick_connect.init.list_all(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.quick_connect.init.list_all instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="list_quick_connects",
        op_kwargs={
            "InstanceId": instance_id,
            "NextToken": next_token,
            "MaxResults": max_results,
            "QuickConnectTypes": quick_connect_types,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Adds or overwrites one or more tags for the specified AppStream 2.0 resource. You can tag AppStream 2.0 image builders, images, fleets, and stacks. Each tag consists of a key and an optional value. If a resource already has a tag with the same key, this operation updates its value. To list the current tags for your resources, use ListTagsForResource. To disassociate tags from your resources, use UntagResource. For more information about tags, see Tagging Your Resources in the Amazon AppStream 2.0 Administration Guide.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource.
        tags(Dict): The tags to associate. A tag is a key-value pair, and the value is optional. For example, Environment=Test. If you do not specify a value, Environment=.  If you do not specify a value, the value is set to an empty string. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following special characters:  _ . : / = + \ - @.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates one or more specified tags from the specified AppStream 2.0 resource. To list the current tags for your resources, use ListTagsForResource. For more information about tags, see Tagging Your Resources in the Amazon AppStream 2.0 Administration Guide.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource.
        tag_keys(List): The tag keys for the tags to disassociate.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    agent_ids: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists agents or connectors as specified by ID or other filters. All agents/connectors associated with your user account can be listed if you call DescribeAgents as is without passing any parameters.

    Args:
        agent_ids(List, optional): The agent or the Connector IDs for which you want information. If you specify no IDs, the system returns information about all agents/Connectors associated with your AWS user account. Defaults to None.
        filters(List, optional): You can filter the request using various logical operators and a key-value format. For example:   {"key": "collectionStatus", "value": "STARTED"} . Defaults to None.
        max_results(int, optional): The total number of agents/Connectors to return in a single page of output. The maximum value is 100. Defaults to None.
        next_token(str, optional): Token to retrieve the next set of results. For example, if you previously specified 100 IDs for DescribeAgentsRequest$agentIds but set DescribeAgentsRequest$maxResults to 10, you received a set of 10 results along with a token. Use that token in this query to get the next set of 10. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.discovery.agent.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.discovery.agent.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="discovery",
        operation="describe_agents",
        op_kwargs={
            "agentIds": agent_ids,
            "filters": filters,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the scaling parameters configured for a domain. A domain's scaling parameters specify the desired search instance type and replication count. For more information, see Configuring Scaling Options in the Amazon CloudSearch Developer Guide.

    Args:
        domain_name(str): A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.scaling_parameter.describe_all(
                ctx, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.scaling_parameter.describe_all domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="describe_scaling_parameters",
        op_kwargs={"DomainName": domain_name},
    )


async def update_multiple(hub, ctx, domain_name: str, scaling_parameters: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Configures scaling parameters for a domain. A domain's scaling parameters specify the desired search instance type and replication count. Amazon CloudSearch will still automatically scale your domain based on the volume of data and traffic, but not below the desired instance type and replication count. If the Multi-AZ option is enabled, these values control the resources used per Availability Zone. For more information, see Configuring Scaling Options in the Amazon CloudSearch Developer Guide.

    Args:
        domain_name(str): A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
        scaling_parameters(Dict): The desired instance type and desired number of replicas of each index partition.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.scaling_parameter.update_multiple(
                ctx, domain_name=value, scaling_parameters=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.scaling_parameter.update_multiple domain_name=value, scaling_parameters=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="update_scaling_parameters",
        op_kwargs={"DomainName": domain_name, "ScalingParameters": scaling_parameters},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def check(hub, ctx, domain_name: str, auth_code: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Checks whether a domain name can be transferred to Amazon Route 53.

    Args:
        domain_name(str): The name of the domain that you want to transfer to Route 53. The top-level domain (TLD), such as .com, must be a TLD that Route 53 supports. For a list of supported TLDs, see Domains that You Can Register with Amazon Route 53 in the Amazon Route 53 Developer Guide. The domain name can contain only the following characters:   Letters a through z. Domain names are not case sensitive.   Numbers 0 through 9.   Hyphen (-). You can't specify a hyphen at the beginning or end of a label.    Period (.) to separate the labels in the name, such as the . in example.com.  .
        auth_code(str, optional): If the registrar for the top-level domain (TLD) requires an authorization code to transfer the domain, the code that you got from the current registrar for the domain. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.domain.transferability.check(
                ctx, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.domain.transferability.check domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="check_domain_transferability",
        op_kwargs={"DomainName": domain_name, "AuthCode": auth_code},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def opt(hub, ctx, phone_number: str) -> Dict:
    r"""
    **Autogenerated function**

    Use this request to opt in a phone number that is opted out, which enables you to resume sending SMS messages to the number. You can opt in a phone number only once every 30 days.

    Args:
        phone_number(str): The phone number to opt in. Use E.164 format.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.in_phone_number.opt(ctx, phone_number=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.in_phone_number.opt phone_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="opt_in_phone_number",
        op_kwargs={"phoneNumber": phone_number},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def admin(
    hub, ctx, user_pool_id: str, username: str, user_attribute_names: List
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the user attributes in a user pool as an administrator. Works on any user. Calling this action requires developer credentials.

    Args:
        user_pool_id(str): The user pool ID for the user pool where you want to delete user attributes.
        username(str): The user name of the user from which you would like to delete attributes.
        user_attribute_names(List): An array of strings representing the user attribute names you wish to delete. For custom attributes, you must prepend the custom: prefix to the attribute name.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.delete_user.attribute.admin(
                ctx, user_pool_id=value, username=value, user_attribute_names=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.delete_user.attribute.admin user_pool_id=value, username=value, user_attribute_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="admin_delete_user_attributes",
        op_kwargs={
            "UserPoolId": user_pool_id,
            "Username": username,
            "UserAttributeNames": user_attribute_names,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def tag(hub, ctx, resource_id: str, tags: List) -> None:
    r"""
    **Autogenerated function**

    Adds one or more tags to the specified resource. Currently, you can attach tags to the following resources in AWS Organizations.   AWS account   Organization root   Organizational unit (OU)   Policy (any type)   This operation can be called only from the organization's management account.

    Args:
        resource_id(str): The ID of the resource to add a tag to.
        tags(List): A list of tags to add to the specified resource. You can specify any of the following taggable resources.   AWS account – specify the account ID number.   Organizational unit – specify the OU ID that begins with ou- and looks similar to: ou-1a2b-34uvwxyz     Root – specify the root ID that begins with r- and looks similar to: r-1a2b     Policy – specify the policy ID that begins with p- andlooks similar to: p-12abcdefg3     For each tag in the list, you must specify both a tag key and a value. You can set the value to an empty string, but you can't set it to null.  If any one of the tags is invalid or if you exceed the allowed number of tags for an account user, then the entire request fails and the account is not created. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.resource.tag(ctx, resource_id=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.resource.tag resource_id=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="tag_resource",
        op_kwargs={"ResourceId": resource_id, "Tags": tags},
    )


async def untag(hub, ctx, resource_id: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Removes any tags with the specified keys from the specified resource. You can attach tags to the following resources in AWS Organizations.   AWS account   Organization root   Organizational unit (OU)   Policy (any type)   This operation can be called only from the organization's management account.

    Args:
        resource_id(str): The ID of the resource to remove a tag from. You can specify any of the following taggable resources.   AWS account – specify the account ID number.   Organizational unit – specify the OU ID that begins with ou- and looks similar to: ou-1a2b-34uvwxyz     Root – specify the root ID that begins with r- and looks similar to: r-1a2b     Policy – specify the policy ID that begins with p- andlooks similar to: p-12abcdefg3    .
        tag_keys(List): The list of keys for tags to remove from the specified resource.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.resource.untag(
                ctx, resource_id=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.resource.untag resource_id=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="untag_resource",
        op_kwargs={"ResourceId": resource_id, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    replication_instance_identifier: str,
    replication_instance_class: str,
    allocated_storage: int = None,
    vpc_security_group_ids: List = None,
    availability_zone: str = None,
    replication_subnet_group_identifier: str = None,
    preferred_maintenance_window: str = None,
    multi_az: bool = None,
    engine_version: str = None,
    auto_minor_version_upgrade: bool = None,
    tags: List = None,
    kms_key_id: str = None,
    publicly_accessible: bool = None,
    dns_name_servers: str = None,
    resource_identifier: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates the replication instance using the specified parameters. DMS requires that your account have certain roles with appropriate permissions before you can create a replication instance. For information on the required roles, see Creating the IAM Roles to Use With the CLI and DMS API. For information on the required permissions, see IAM Permissions Needed to Use DMS.

    Args:
        replication_instance_identifier(str): The replication instance identifier. This parameter is stored as a lowercase string. Constraints:   Must contain 1-63 alphanumeric characters or hyphens.   First character must be a letter.   Can't end with a hyphen or contain two consecutive hyphens.   Example: myrepinstance .
        allocated_storage(int, optional): The amount of storage (in gigabytes) to be initially allocated for the replication instance. Defaults to None.
        replication_instance_class(str): The compute and memory capacity of the replication instance as defined for the specified replication instance class. For example to specify the instance class dms.c4.large, set this parameter to "dms.c4.large". For more information on the settings and capacities for the available replication instance classes, see  Selecting the right DMS replication instance for your migration. .
        vpc_security_group_ids(List, optional):  Specifies the VPC security group to be used with the replication instance. The VPC security group must work with the VPC containing the replication instance. . Defaults to None.
        availability_zone(str, optional): The Availability Zone where the replication instance will be created. The default value is a random, system-chosen Availability Zone in the endpoint's Region, for example: us-east-1d . Defaults to None.
        replication_subnet_group_identifier(str, optional): A subnet group to associate with the replication instance. Defaults to None.
        preferred_maintenance_window(str, optional): The weekly time range during which system maintenance can occur, in Universal Coordinated Time (UTC).  Format: ddd:hh24:mi-ddd:hh24:mi  Default: A 30-minute window selected at random from an 8-hour block of time per Region, occurring on a random day of the week. Valid Days: Mon, Tue, Wed, Thu, Fri, Sat, Sun Constraints: Minimum 30-minute window. Defaults to None.
        multi_az(bool, optional):  Specifies whether the replication instance is a Multi-AZ deployment. You can't set the AvailabilityZone parameter if the Multi-AZ parameter is set to true. . Defaults to None.
        engine_version(str, optional): The engine version number of the replication instance. If an engine version number is not specified when a replication instance is created, the default is the latest engine version available. Defaults to None.
        auto_minor_version_upgrade(bool, optional): A value that indicates whether minor engine upgrades are applied automatically to the replication instance during the maintenance window. This parameter defaults to true. Default: true . Defaults to None.
        tags(List, optional): One or more tags to be assigned to the replication instance. Defaults to None.
        kms_key_id(str, optional): An KMS key identifier that is used to encrypt the data on the replication instance. If you don't specify a value for the KmsKeyId parameter, then DMS uses your default encryption key. KMS creates the default encryption key for your account. Your account has a different default encryption key for each Region. Defaults to None.
        publicly_accessible(bool, optional):  Specifies the accessibility options for the replication instance. A value of true represents an instance with a public IP address. A value of false represents an instance with a private IP address. The default value is true. . Defaults to None.
        dns_name_servers(str, optional): A list of custom DNS name servers supported for the replication instance to access your on-premise source or target database. This list overrides the default name servers supported by the replication instance. You can specify a comma-separated list of internet addresses for up to four on-premise DNS name servers. For example: "1.1.1.1,2.2.2.2,3.3.3.3,4.4.4.4" . Defaults to None.
        resource_identifier(str, optional): A friendly name for the resource identifier at the end of the EndpointArn response parameter that is returned in the created Endpoint object. The value for this parameter can have up to 31 characters. It can contain only ASCII letters, digits, and hyphen ('-'). Also, it can't end with a hyphen or contain two consecutive hyphens, and can only begin with a letter, such as Example-App-ARN1. For example, this value might result in the EndpointArn value arn:aws:dms:eu-west-1:012345678901:rep:Example-App-ARN1. If you don't specify a ResourceIdentifier value, DMS generates a default identifier value for the end of EndpointArn. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.replication.instance.init.create(
                ctx, replication_instance_identifier=value, replication_instance_class=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.replication.instance.init.create replication_instance_identifier=value, replication_instance_class=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="create_replication_instance",
        op_kwargs={
            "ReplicationInstanceIdentifier": replication_instance_identifier,
            "AllocatedStorage": allocated_storage,
            "ReplicationInstanceClass": replication_instance_class,
            "VpcSecurityGroupIds": vpc_security_group_ids,
            "AvailabilityZone": availability_zone,
            "ReplicationSubnetGroupIdentifier": replication_subnet_group_identifier,
            "PreferredMaintenanceWindow": preferred_maintenance_window,
            "MultiAZ": multi_az,
            "EngineVersion": engine_version,
            "AutoMinorVersionUpgrade": auto_minor_version_upgrade,
            "Tags": tags,
            "KmsKeyId": kms_key_id,
            "PubliclyAccessible": publicly_accessible,
            "DnsNameServers": dns_name_servers,
            "ResourceIdentifier": resource_identifier,
        },
    )


async def delete(hub, ctx, replication_instance_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified replication instance.  You must delete any migration tasks that are associated with the replication instance before you can delete it.

    Args:
        replication_instance_arn(str): The Amazon Resource Name (ARN) of the replication instance to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.replication.instance.init.delete(
                ctx, replication_instance_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.replication.instance.init.delete replication_instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="delete_replication_instance",
        op_kwargs={"ReplicationInstanceArn": replication_instance_arn},
    )


async def describe_all(
    hub, ctx, filters: List = None, max_records: int = None, marker: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about replication instances for your account in the current region.

    Args:
        filters(List, optional): Filters applied to replication instances. Valid filter names: replication-instance-arn | replication-instance-id | replication-instance-class | engine-version. Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.replication.instance.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.replication.instance.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="describe_replication_instances",
        op_kwargs={"Filters": filters, "MaxRecords": max_records, "Marker": marker},
    )


async def modify(
    hub,
    ctx,
    replication_instance_arn: str,
    allocated_storage: int = None,
    apply_immediately: bool = None,
    replication_instance_class: str = None,
    vpc_security_group_ids: List = None,
    preferred_maintenance_window: str = None,
    multi_az: bool = None,
    engine_version: str = None,
    allow_major_version_upgrade: bool = None,
    auto_minor_version_upgrade: bool = None,
    replication_instance_identifier: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the replication instance to apply new settings. You can change one or more parameters by specifying these parameters and the new values in the request. Some settings are applied during the maintenance window.

    Args:
        replication_instance_arn(str): The Amazon Resource Name (ARN) of the replication instance.
        allocated_storage(int, optional): The amount of storage (in gigabytes) to be allocated for the replication instance. Defaults to None.
        apply_immediately(bool, optional): Indicates whether the changes should be applied immediately or during the next maintenance window. Defaults to None.
        replication_instance_class(str, optional): The compute and memory capacity of the replication instance as defined for the specified replication instance class. For example to specify the instance class dms.c4.large, set this parameter to "dms.c4.large". For more information on the settings and capacities for the available replication instance classes, see  Selecting the right DMS replication instance for your migration. . Defaults to None.
        vpc_security_group_ids(List, optional):  Specifies the VPC security group to be used with the replication instance. The VPC security group must work with the VPC containing the replication instance. . Defaults to None.
        preferred_maintenance_window(str, optional): The weekly time range (in UTC) during which system maintenance can occur, which might result in an outage. Changing this parameter does not result in an outage, except in the following situation, and the change is asynchronously applied as soon as possible. If moving this window to the current time, there must be at least 30 minutes between the current time and end of the window to ensure pending changes are applied. Default: Uses existing setting Format: ddd:hh24:mi-ddd:hh24:mi Valid Days: Mon | Tue | Wed | Thu | Fri | Sat | Sun Constraints: Must be at least 30 minutes. Defaults to None.
        multi_az(bool, optional):  Specifies whether the replication instance is a Multi-AZ deployment. You can't set the AvailabilityZone parameter if the Multi-AZ parameter is set to true. . Defaults to None.
        engine_version(str, optional): The engine version number of the replication instance. When modifying a major engine version of an instance, also set AllowMajorVersionUpgrade to true. Defaults to None.
        allow_major_version_upgrade(bool, optional): Indicates that major version upgrades are allowed. Changing this parameter does not result in an outage, and the change is asynchronously applied as soon as possible. This parameter must be set to true when specifying a value for the EngineVersion parameter that is a different major version than the replication instance's current version. Defaults to None.
        auto_minor_version_upgrade(bool, optional): A value that indicates that minor version upgrades are applied automatically to the replication instance during the maintenance window. Changing this parameter doesn't result in an outage, except in the case described following. The change is asynchronously applied as soon as possible.  An outage does result if these factors apply:    This parameter is set to true during the maintenance window.   A newer minor version is available.    DMS has enabled automatic patching for the given engine version.   . Defaults to None.
        replication_instance_identifier(str, optional): The replication instance identifier. This parameter is stored as a lowercase string. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.replication.instance.init.modify(
                ctx, replication_instance_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.replication.instance.init.modify replication_instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="modify_replication_instance",
        op_kwargs={
            "ReplicationInstanceArn": replication_instance_arn,
            "AllocatedStorage": allocated_storage,
            "ApplyImmediately": apply_immediately,
            "ReplicationInstanceClass": replication_instance_class,
            "VpcSecurityGroupIds": vpc_security_group_ids,
            "PreferredMaintenanceWindow": preferred_maintenance_window,
            "MultiAZ": multi_az,
            "EngineVersion": engine_version,
            "AllowMajorVersionUpgrade": allow_major_version_upgrade,
            "AutoMinorVersionUpgrade": auto_minor_version_upgrade,
            "ReplicationInstanceIdentifier": replication_instance_identifier,
        },
    )


async def reboot(
    hub, ctx, replication_instance_arn: str, force_failover: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Reboots a replication instance. Rebooting results in a momentary outage, until the replication instance becomes available again.

    Args:
        replication_instance_arn(str): The Amazon Resource Name (ARN) of the replication instance.
        force_failover(bool, optional): If this parameter is true, the reboot is conducted through a Multi-AZ failover. (If the instance isn't configured for Multi-AZ, then you can't specify true.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.replication.instance.init.reboot(
                ctx, replication_instance_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.replication.instance.init.reboot replication_instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="reboot_replication_instance",
        op_kwargs={
            "ReplicationInstanceArn": replication_instance_arn,
            "ForceFailover": force_failover,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    security_profile_target_arn: str,
    next_token: str = None,
    max_results: int = None,
    recursive: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the Device Defender security profiles attached to a target (thing group).

    Args:
        next_token(str, optional): The token for the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return at one time. Defaults to None.
        recursive(bool, optional): If true, return child groups too. Defaults to None.
        security_profile_target_arn(str): The ARN of the target (thing group) whose attached security profiles you want to get.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.security_profile.for_target.list(
                ctx, security_profile_target_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.security_profile.for_target.list security_profile_target_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_security_profiles_for_target",
        op_kwargs={
            "nextToken": next_token,
            "maxResults": max_results,
            "recursive": recursive,
            "securityProfileTargetArn": security_profile_target_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    service_update_name: str = None,
    replication_group_ids: List = None,
    cache_cluster_ids: List = None,
    engine: str = None,
    service_update_status: List = None,
    service_update_time_range: Dict = None,
    update_action_status: List = None,
    show_node_level_update_status: bool = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns details of the update actions

    Args:
        service_update_name(str, optional): The unique ID of the service update. Defaults to None.
        replication_group_ids(List, optional): The replication group IDs. Defaults to None.
        cache_cluster_ids(List, optional): The cache cluster IDs. Defaults to None.
        engine(str, optional): The Elasticache engine to which the update applies. Either Redis or Memcached . Defaults to None.
        service_update_status(List, optional): The status of the service update. Defaults to None.
        service_update_time_range(Dict, optional): The range of time specified to search for service updates that are in available status. Defaults to None.
        update_action_status(List, optional): The status of the update action. Defaults to None.
        show_node_level_update_status(bool, optional): Dictates whether to include node level update status in the response . Defaults to None.
        max_records(int, optional): The maximum number of records to include in the response. Defaults to None.
        marker(str, optional): An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.update_action.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.update_action.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="describe_update_actions",
        op_kwargs={
            "ServiceUpdateName": service_update_name,
            "ReplicationGroupIds": replication_group_ids,
            "CacheClusterIds": cache_cluster_ids,
            "Engine": engine,
            "ServiceUpdateStatus": service_update_status,
            "ServiceUpdateTimeRange": service_update_time_range,
            "UpdateActionStatus": update_action_status,
            "ShowNodeLevelUpdateStatus": show_node_level_update_status,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def detect(hub, ctx, image: Dict, filters: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

    Detects text in the input image and converts it into machine-readable text. Pass the input image as base64-encoded image bytes or as a reference to an image in an Amazon S3 bucket. If you use the AWS CLI to call Amazon Rekognition operations, you must pass it as a reference to an image in an Amazon S3 bucket. For the AWS CLI, passing image bytes is not supported. The image must be either a .png or .jpeg formatted file.  The DetectText operation returns text in an array of TextDetection elements, TextDetections. Each TextDetection element provides information about a single word or line of text that was detected in the image.  A word is one or more ISO basic latin script characters that are not separated by spaces. DetectText can detect up to 50 words in an image. A line is a string of equally spaced words. A line isn't necessarily a complete sentence. For example, a driver's license number is detected as a line. A line ends when there is no aligned text after it. Also, a line ends when there is a large gap between words, relative to the length of the words. This means, depending on the gap between words, Amazon Rekognition may detect multiple lines in text aligned in the same direction. Periods don't represent the end of a line. If a sentence spans multiple lines, the DetectText operation returns multiple lines. To determine whether a TextDetection element is a line of text or a word, use the TextDetection object Type field.  To be detected, text must be within +/- 90 degrees orientation of the horizontal axis. For more information, see DetectText in the Amazon Rekognition Developer Guide.

    Args:
        image(Dict): The input image as base64-encoded bytes or an Amazon S3 object. If you use the AWS CLI to call Amazon Rekognition operations, you can't pass image bytes.  If you are using an AWS SDK to call Amazon Rekognition, you might not need to base64-encode image bytes passed using the Bytes field. For more information, see Images in the Amazon Rekognition developer guide.
        filters(Dict, optional): Optional parameters that let you set the criteria that the text must meet to be included in your response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.text.init.detect(ctx, image=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.text.init.detect image=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="detect_text",
        op_kwargs={"Image": image, "Filters": filters},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    configuration: Dict,
    map_name: str,
    pricing_plan: str,
    description: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a map resource in your AWS account, which provides map tiles of different styles sourced from global location data providers.

    Args:
        configuration(Dict): Specifies the map style selected from an available data provider.
        description(str, optional): An optional description for the map resource. Defaults to None.
        map_name(str): The name for the map resource. Requirements:   Must contain only alphanumeric characters (A–Z, a–z, 0–9), hyphens (-), periods (.), and underscores (_).    Must be a unique map resource name.    No spaces allowed. For example, ExampleMap.  .
        pricing_plan(str): Specifies the pricing plan for your map resource. For additional details and restrictions on each pricing plan option, see the Amazon Location Service pricing page.
        tags(Dict, optional): Applies one or more tags to the map resource. A tag is a key-value pair helps manage, identify, search, and filter your resources by labelling them. Format: "key" : "value"  Restrictions:   Maximum 50 tags per resource   Each resource tag must be unique with a maximum of one value.   Maximum key length: 128 Unicode characters in UTF-8   Maximum value length: 256 Unicode characters in UTF-8   Can use alphanumeric characters (A–Z, a–z, 0–9), and the following characters: + - = . _ : / @.   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.map_.init.create(
                ctx, configuration=value, map_name=value, pricing_plan=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.map_.init.create configuration=value, map_name=value, pricing_plan=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="create_map",
        op_kwargs={
            "Configuration": configuration,
            "Description": description,
            "MapName": map_name,
            "PricingPlan": pricing_plan,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, map_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a map resource from your AWS account.  This operation deletes the resource permanently. If the map is being used in an application, the map may not render.

    Args:
        map_name(str): The name of the map resource to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.map_.init.delete(ctx, map_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.map_.init.delete map_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="delete_map",
        op_kwargs={"MapName": map_name},
    )


async def describe(hub, ctx, map_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the map resource details.

    Args:
        map_name(str): The name of the map resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.map_.init.describe(ctx, map_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.map_.init.describe map_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="describe_map",
        op_kwargs={"MapName": map_name},
    )


async def update(
    hub, ctx, map_name: str, description: str = None, pricing_plan: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified properties of a given map resource.

    Args:
        description(str, optional): Updates the description for the map resource. Defaults to None.
        map_name(str): The name of the map resource to update.
        pricing_plan(str, optional): Updates the pricing plan for the map resource. For more information about each pricing plan option restrictions, see Amazon Location Service pricing. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.map_.init.update(ctx, map_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.map_.init.update map_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="update_map",
        op_kwargs={
            "Description": description,
            "MapName": map_name,
            "PricingPlan": pricing_plan,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, model_endpoint: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes a SageMaker model from Amazon Fraud Detector. You can remove an Amazon SageMaker model if it is not associated with a detector version. Removing a SageMaker model disconnects it from Amazon Fraud Detector, but the model remains available in SageMaker.

    Args:
        model_endpoint(str): The endpoint of the Amazon Sagemaker model to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.external_model.delete(ctx, model_endpoint=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.external_model.delete model_endpoint=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="delete_external_model",
        op_kwargs={"modelEndpoint": model_endpoint},
    )


async def get_all(
    hub,
    ctx,
    model_endpoint: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the details for one or more Amazon SageMaker models that have been imported into the service. This is a paginated API. If you provide a null maxResults, this actions retrieves a maximum of 10 records per page. If you provide a maxResults, the value must be between 5 and 10. To get the next page results, provide the pagination token from the GetExternalModelsResult as part of your request. A null pagination token fetches the records from the beginning.

    Args:
        model_endpoint(str, optional): The Amazon SageMaker model endpoint. Defaults to None.
        next_token(str, optional): The next page token for the request. Defaults to None.
        max_results(int, optional): The maximum number of objects to return for the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.external_model.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.external_model.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="get_external_models",
        op_kwargs={
            "modelEndpoint": model_endpoint,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def put(
    hub,
    ctx,
    model_endpoint: str,
    model_source: str,
    invoke_model_endpoint_role_arn: str,
    input_configuration: Dict,
    output_configuration: Dict,
    model_endpoint_status: str,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates an Amazon SageMaker model endpoint. You can also use this action to update the configuration of the model endpoint, including the IAM role and/or the mapped variables.

    Args:
        model_endpoint(str): The model endpoints name.
        model_source(str): The source of the model.
        invoke_model_endpoint_role_arn(str): The IAM role used to invoke the model endpoint.
        input_configuration(Dict): The model endpoint input configuration.
        output_configuration(Dict): The model endpoint output configuration.
        model_endpoint_status(str): The model endpoint’s status in Amazon Fraud Detector.
        tags(List, optional): A collection of key and value pairs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.external_model.put(
                ctx,
                model_endpoint=value,
                model_source=value,
                invoke_model_endpoint_role_arn=value,
                input_configuration=value,
                output_configuration=value,
                model_endpoint_status=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.external_model.put model_endpoint=value, model_source=value, invoke_model_endpoint_role_arn=value, input_configuration=value, output_configuration=value, model_endpoint_status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="put_external_model",
        op_kwargs={
            "modelEndpoint": model_endpoint,
            "modelSource": model_source,
            "invokeModelEndpointRoleArn": invoke_model_endpoint_role_arn,
            "inputConfiguration": input_configuration,
            "outputConfiguration": output_configuration,
            "modelEndpointStatus": model_endpoint_status,
            "tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    index_id: str,
    type_: str,
    configuration: Dict = None,
    description: str = None,
    schedule: str = None,
    role_arn: str = None,
    tags: List = None,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a data source that you use to with an Amazon Kendra index.  You specify a name, data source connector type and description for your data source. You also specify configuration information such as document metadata (author, source URI, and so on) and user context information.  CreateDataSource is a synchronous operation. The operation returns 200 if the data source was successfully created. Otherwise, an exception is raised.

    Args:
        name(str): A unique name for the data source. A data source name can't be changed without deleting and recreating the data source.
        index_id(str): The identifier of the index that should be associated with this data source.
        type_(str): The type of repository that contains the data source.
        configuration(Dict, optional): The connector configuration information that is required to access the repository. You can't specify the Configuration parameter when the Type parameter is set to CUSTOM. If you do, you receive a ValidationException exception. The Configuration parameter is required for all other data sources. Defaults to None.
        description(str, optional): A description for the data source. Defaults to None.
        schedule(str, optional): Sets the frequency that Amazon Kendra will check the documents in your repository and update the index. If you don't set a schedule Amazon Kendra will not periodically update the index. You can call the StartDataSourceSyncJob operation to update the index. You can't specify the Schedule parameter when the Type parameter is set to CUSTOM. If you do, you receive a ValidationException exception. Defaults to None.
        role_arn(str, optional): The Amazon Resource Name (ARN) of a role with permission to access the data source. For more information, see IAM Roles for Amazon Kendra. You can't specify the RoleArn parameter when the Type parameter is set to CUSTOM. If you do, you receive a ValidationException exception. The RoleArn parameter is required for all other data sources. Defaults to None.
        tags(List, optional): A list of key-value pairs that identify the data source. You can use the tags to identify and organize your resources and to control access to resources. Defaults to None.
        client_token(str, optional): A token that you provide to identify the request to create a data source. Multiple calls to the CreateDataSource operation with the same client token will create only one data source. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.data_source.init.create(
                ctx, name=value, index_id=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.data_source.init.create name=value, index_id=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="create_data_source",
        op_kwargs={
            "Name": name,
            "IndexId": index_id,
            "Type": type_,
            "Configuration": configuration,
            "Description": description,
            "Schedule": schedule,
            "RoleArn": role_arn,
            "Tags": tags,
            "ClientToken": client_token,
        },
    )


async def delete(hub, ctx, id_: str, index_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an Amazon Kendra data source. An exception is not thrown if the data source is already being deleted. While the data source is being deleted, the Status field returned by a call to the DescribeDataSource operation is set to DELETING. For more information, see Deleting Data Sources.

    Args:
        id_(str): The unique identifier of the data source to delete.
        index_id(str): The unique identifier of the index associated with the data source.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.data_source.init.delete(ctx, id_=value, index_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.data_source.init.delete id_=value, index_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="delete_data_source",
        op_kwargs={"Id": id_, "IndexId": index_id},
    )


async def describe(hub, ctx, id_: str, index_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a Amazon Kendra data source.

    Args:
        id_(str): The unique identifier of the data source to describe.
        index_id(str): The identifier of the index that contains the data source.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.data_source.init.describe(ctx, id_=value, index_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.data_source.init.describe id_=value, index_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="describe_data_source",
        op_kwargs={"Id": id_, "IndexId": index_id},
    )


async def list_all(
    hub, ctx, index_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the data sources that you have created.

    Args:
        index_id(str): The identifier of the index that contains the data source.
        next_token(str, optional): If the previous response was incomplete (because there is more data to retrieve), Amazon Kendra returns a pagination token in the response. You can use this pagination token to retrieve the next set of data sources (DataSourceSummaryItems). . Defaults to None.
        max_results(int, optional): The maximum number of data sources to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.data_source.init.list_all(ctx, index_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.data_source.init.list_all index_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="list_data_sources",
        op_kwargs={
            "IndexId": index_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    id_: str,
    index_id: str,
    name: str = None,
    configuration: Dict = None,
    description: str = None,
    schedule: str = None,
    role_arn: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Updates an existing Amazon Kendra data source.

    Args:
        id_(str): The unique identifier of the data source to update.
        name(str, optional): The name of the data source to update. The name of the data source can't be updated. To rename a data source you must delete the data source and re-create it. Defaults to None.
        index_id(str): The identifier of the index that contains the data source to update.
        configuration(Dict, optional): Configuration information for a Amazon Kendra data source. Defaults to None.
        description(str, optional): The new description for the data source. Defaults to None.
        schedule(str, optional): The new update schedule for the data source. Defaults to None.
        role_arn(str, optional): The Amazon Resource Name (ARN) of the new role to use when the data source is accessing resources on your behalf. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.data_source.init.update(ctx, id_=value, index_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.data_source.init.update id_=value, index_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="update_data_source",
        op_kwargs={
            "Id": id_,
            "Name": name,
            "IndexId": index_id,
            "Configuration": configuration,
            "Description": description,
            "Schedule": schedule,
            "RoleArn": role_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, cluster_name: str, client_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Create a new cluster. A cluster is a set of redundant Regional endpoints against which you can run API calls to update or get the state of one or more routing controls. Each cluster has a name, status, Amazon Resource Name (ARN), and an array of the five cluster endpoints (one for each supported Amazon Web Services Region) that you can use with API calls to the Amazon Route 53 Application Recovery Controller cluster data plane.

    Args:
        client_token(str, optional): Unique client idempotency token. Defaults to None.
        cluster_name(str): The name of the cluster.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_control_config.cluster.create(
                ctx, cluster_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_control_config.cluster.create cluster_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-control-config",
        operation="create_cluster",
        op_kwargs={"ClientToken": client_token, "ClusterName": cluster_name},
    )


async def delete(hub, ctx, cluster_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Delete a cluster.

    Args:
        cluster_arn(str): The Amazon Resource Name (ARN) of the cluster that you're deleting.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_control_config.cluster.delete(
                ctx, cluster_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_control_config.cluster.delete cluster_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-control-config",
        operation="delete_cluster",
        op_kwargs={"ClusterArn": cluster_arn},
    )


async def describe(hub, ctx, cluster_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Display the details about a cluster. The response includes the cluster name, endpoints, status, and Amazon Resource Name (ARN).

    Args:
        cluster_arn(str): The Amazon Resource Name (ARN) of the cluster that you're getting details for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_control_config.cluster.describe(
                ctx, cluster_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_control_config.cluster.describe cluster_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-control-config",
        operation="describe_cluster",
        op_kwargs={"ClusterArn": cluster_arn},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns an array of all the clusters in an account.

    Args:
        max_results(int, optional): The number of objects that you want to return with this call. Defaults to None.
        next_token(str, optional): The token that identifies which batch of results you want to see. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_control_config.cluster.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_control_config.cluster.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-control-config",
        operation="list_clusters",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )
